#' tidyndr: A package for analyzing the de-identified patient-level data from the
#' Nigeria National Data Repository (NDR)
#'
#' @description
#' To learn more about tidyndr, refer to the vignettes: \code{browseVignettes(package = "tidyndr")}
#'
#' @docType package
#' @keywords internal
#' @name tidyndr
"_PACKAGE"
NULL
